#
# spec file for package wasm-pack
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wasm-pack
Version:        0.13.1~0
Release:        1.2
Summary:        Your favorite Rust → Wasm workflow tool!
License:        (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND ISC AND MIT
Group:          Development/Languages/Rust
URL:            https://github.com/rustwasm/wasm-pack
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
# Because equals 0.2.97 doesn't work.
Requires:       wasm-bindgen < 0.2.98
Requires:       wasm-bindgen > 0.2.96
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  clang
BuildRequires:  cmake
ExclusiveArch:  %{rust_tier1_arches}

%description
This tool seeks to be a one-stop shop for building and working with rust- generated WebAssembly that
you would like to interop with JavaScript, in the browser or with Node.js. wasm-pack helps you build
rust-generated WebAssembly packages that you could publish to the npm registry, or otherwise use
alongside any javascript packages in workflows that you already use, such as webpack.

%prep
%autosetup -a1

%build
export CC=/usr/bin/clang
export CXX=/usr/bin/clang++
%{cargo_build}

%install
export CC=/usr/bin/clang
export CXX=/usr/bin/clang++
%{cargo_install}

%files
%{_bindir}/wasm-pack

%changelog
* Tue Jan  7 2025 william.brown@suse.com
- Explicitly depend on wasm-bindgen version as these must be updated in lockstep.
- Update to version 0.13.1~0:
  * 0.13.1
  * fix: allow npm binary upgrades
  * Requests using proxy settings from ENV
  * fmt
  * fixup
  * Remove unmaintained dependency atty in favor of stdlib
  * chore(deps): bump actions/download-artifact in /.github/workflows
  * chore: Update binary-install to v0.4.1
* Fri Oct 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add BuildIgnore for libldap-data
  This package is required by lldap in network:ldap and projects branched from
  there. The setup there is broken due to libldap-data. Adding a BuildIgnore
  solves this on package-level.
  As wasm-pack does not depend on libldap-data, this should do no harm.
* Tue Sep 10 2024 William Brown <william.brown@suse.com>
- explicitly depend on cargo to pull in latest compiler revision
* Tue Jul  2 2024 william.brown@suse.com
- Update to version 0.13.0~0:
  * 0.13.0
  * test: Bump version for wasm-bindgen
  * fix: optimize out-dir display
  * feat(webdriver): support geckodriver for `linux-aarch64`
  * chore(deps): bump tar from 6.1.11 to 6.2.1 in /npm
  * ci: undo cachebust
  * fix assumption in prior commit
  * fix prior commit
  * add linux aarch64 to targets; bump binaryen vers.
  * ci: cachebust
  * ci: install firefox on macos-latest
  * ci: use macos-13 github actions runner
  * test: accept new finish message
  * fix: update chromedriver download URL
  * Fix local navigation taking one step too far
  * chore(deps): bump rustls from 0.21.9 to 0.21.11
  * chore(deps): bump follow-redirects from 1.14.9 to 1.15.6 in /npm
  * pkg-dir option for pack and publish commands
  * Fix typo in README.md
  * Remove unused `greet` argument.
  * Add `--target web` to quick start build command
  * Add mingw support to npm package
  * chore: document deno in build target
  * chore: Bump binary-install
  * chore: Update Cargo.lock
  * Update build.md
  * Rewrite wasm_target to use target-libdir
  * chore(deps): bump rustix from 0.37.20 to 0.37.25
  * Update readme
  * Fix passing relative paths to cargo
  * Select correct target for chromedriver
  * Use new endpoints for chromedriver
  * chore(deps): bump rustls-webpki from 0.100.1 to 0.100.2
  * Add option to skip optimization with wasm-opt
  * Fix error and warnings in install script
  * test: update new test to expect main instead of module
  * refactor: rename type_ to ty in ESModulesPackage
  * test: update tests to conform to this change
  * fix: declare ES module in package.json
* Wed Jun 28 2023 william.brown@suse.com
- Update to version 0.12.1~0:
  * 0.12.1
  * Fix value parser for `Option<PathBuf>`
  * Restore --version command
* Mon Jun 19 2023 william.brown@suse.com
- Update to version 0.12.0~0:
  * 0.12.0
  * Respect package.readme in Cargo.toml
  * chore: Run cargo fmt
  * Revert "Respect package.readme in Cargo.toml"
  * cargo update
  * Invalid wasm-bindgen config is handled by toml parser
  * update other deps as well
  * update to clap 4 from structopt
  * Turn off cargo colors during log level test
  * chore: Use rust-toolchain@stable
  * chore: Update Cargo.lock
  * Revert CHANGELOG
  * Respect package.readme in Cargo.toml
  * Add sanity test for custom target directory
  * Fix getting the target-dir in wasm_bindgen_build
  * assert non-existence of other files as well
  * remove reqwest from dev-deps
  * rm missing feature from cargo test
  * alias no-pack with no-package
  * Replace curl with ureq
  * fix: missing reference
  * fix: removes `--always-auth` from `npm login`
  * chore(deps): bump minimatch from 3.0.4 to 3.1.2 in /npm
  * add package version to header
  * revert change for var
  * added USER-AGENT header for http GET request
  * Replace unmaintained actions-rs/toolchain action in CI workflows
  * Add option: omit_default_module_path
  * fix: bump cargo-generate version to 0.18.2
  * Don't hide install options behind link
  * feat(build): --no-pack flag
* Tue May 23 2023 william.brown@suse.com
- Update to version 0.11.1~0:
  * 0.11.1
  * Fix usage of locally installed `wasm-opt`
  * chore(deps): bump openssl from 0.10.46 to 0.10.48
  * fix: wasm-pack bin script entry
* Thu Apr 13 2023 William Brown <william.brown@suse.com>
- bsc#1210367 - CVE-2023-26964 - hyper,h2: stream stacking when H2 processing HTTP2 RST_STREAM frames
* Mon Mar 20 2023 elimat@opensuse.org
- bsc#1208562 - CVE-2022-31394 - the version of hyper used was vulnerable to dos
  through header manipulation.
- Update to version 0.11.0~0:
  * 0.11.0
  * chore(deps): bump minimatch from 3.0.4 to 3.1.2 in /npm
  * Update npm installation link
  * chore(deps): bump openssl-src from 111.24.0+1.1.1s to 111.25.0+1.1.1t
  * Mark snippets and the bundler target's main file as having side effects
  * Update JamesIves/github-pages-deploy-action in GHA workflow to v4.4.1
  * Update actions/cache in GitHub Actions workflows to v3
  * Update actions/checkout in GitHub Actions workflows to v3
  * Fix some typos
  * Update dependencies
  * Add support for workspace inheritance
  * Update to Rust 2021
  * Fix SPDX license syntax
  * Bump dependencies
  * Use binary-install v0.1.0
  * chore(deps): bump bzip2 from 0.4.3 to 0.4.4
  * Bump binaryen to version 111
  * Use prebuilt cargo-generate binary on aarch64-macos
  * Update mdbook to v0.4
  * Fix flaky unit tests due to non-existent cache
  * Update dependencies
  * Bump binaryen version to 110
  * Correctly download libbinaryen.dylib on macos
  * Switch from failure to anyhow
  * Apply patches from @printfn
  * Test URL-building matrix
  * Fix windows x86_64 binaryen toolchain download URL
  * Fix macos install target path
  * Make x86 32bit an unsupported installation target
  * Fix binaryen toolchain URL
  * Add Linux arm64 support
  * Pass --enable-reference-types to wasm-opt
  * Pass through --weak-refs --reference-types flags to bindgen
  * fix: adds back run.js to npm installer
  * Make Deno target available
  * small fixes
  * Update non-rustup-setups.md
  * Update mod.rs
  * chore: adds run.js back
  * chore: updates binary-install to v1.0.0
  * Add suppot for more platforms to installer script
  * Replace two mentions of `wasm-pack init` with `wasm-pack build` in the docs.
  * fix(#1076): `--target-dir` as extra option is now considered as expected
  * fix(typo): considerations.md
* Tue Feb 14 2023 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Jan 13 2023 William Brown <william.brown@suse.com>
- bsc#1207039 - CVE-2023-22895 - update bzip2 crate
- Update of vendored dependencies
* Wed Aug 24 2022 elimat@opensuse.org
- Update to version 0.10.3~0:
  * 0.10.3
  * chore(deps): bump regex from 1.5.4 to 1.5.6
  * chore(deps): bump openssl-src from 111.17.0+1.1.1m to 111.20.0+1.1.1o
  * Update release.yml
  * Clean up package.json from previous runs
  * Do not remove the pkg directory
  * 0.10.2
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Thu Apr 21 2022 William Brown <william.brown@suse.com>
- Initial addition of wasm-pack
